==> duckdb_0.3.2-2.tar.gz: duckdb/src/duckdb/amalgamation-13.cpp <==
#include "src/parser/query_node.cpp"

#include "src/parser/query_node/recursive_cte_node.cpp"

#include "src/parser/query_node/select_node.cpp"

#include "src/parser/query_node/set_operation_node.cpp"

#include "src/parser/result_modifier.cpp"

#include "src/parser/statement/alter_statement.cpp"

#include "src/parser/statement/call_statement.cpp"

#include "src/parser/statement/copy_statement.cpp"

#include "src/parser/statement/create_statement.cpp"

#include "src/parser/statement/delete_statement.cpp"

#include "src/parser/statement/drop_statement.cpp"

#include "src/parser/statement/execute_statement.cpp"

#include "src/parser/statement/explain_statement.cpp"

#include "src/parser/statement/export_statement.cpp"

#include "src/parser/statement/insert_statement.cpp"

#include "src/parser/statement/load_statement.cpp"

#include "src/parser/statement/pragma_statement.cpp"

#include "src/parser/statement/prepare_statement.cpp"

#include "src/parser/statement/relation_statement.cpp"

#include "src/parser/statement/select_statement.cpp"

#include "src/parser/statement/set_statement.cpp"

#include "src/parser/statement/show_statement.cpp"

#include "src/parser/statement/transaction_statement.cpp"

#include "src/parser/statement/update_statement.cpp"

#include "src/parser/statement/vacuum_statement.cpp"

#include "src/parser/tableref.cpp"

#include "src/parser/tableref/basetableref.cpp"

#include "src/parser/tableref/crossproductref.cpp"

#include "src/parser/tableref/emptytableref.cpp"

#include "src/parser/tableref/expressionlistref.cpp"

#include "src/parser/tableref/joinref.cpp"

#include "src/parser/tableref/subqueryref.cpp"

#include "src/parser/tableref/table_function.cpp"

#include "src/parser/transform/constraint/transform_constraint.cpp"

#include "src/parser/transform/expression/transform_array_access.cpp"

#include "src/parser/transform/expression/transform_bool_expr.cpp"

#include "src/parser/transform/expression/transform_case.cpp"

#include "src/parser/transform/expression/transform_cast.cpp"

#include "src/parser/transform/expression/transform_coalesce.cpp"

#include "src/parser/transform/expression/transform_columnref.cpp"

#include "src/parser/transform/expression/transform_constant.cpp"

#include "src/parser/transform/expression/transform_expression.cpp"

#include "src/parser/transform/expression/transform_function.cpp"

#include "src/parser/transform/expression/transform_grouping_function.cpp"

#include "src/parser/transform/expression/transform_interval.cpp"

#include "src/parser/transform/expression/transform_is_null.cpp"

==> duckdb_0.3.4-1.tar.gz: duckdb/src/duckdb/amalgamation-13.cpp <==
#include "src/parser/parsed_expression.cpp"

#include "src/parser/parsed_expression_iterator.cpp"

#include "src/parser/parser.cpp"

#include "src/parser/query_error_context.cpp"

#include "src/parser/query_node.cpp"

#include "src/parser/query_node/recursive_cte_node.cpp"

#include "src/parser/query_node/select_node.cpp"

#include "src/parser/query_node/set_operation_node.cpp"

#include "src/parser/result_modifier.cpp"

#include "src/parser/statement/alter_statement.cpp"

#include "src/parser/statement/call_statement.cpp"

#include "src/parser/statement/copy_statement.cpp"

#include "src/parser/statement/create_statement.cpp"

#include "src/parser/statement/delete_statement.cpp"

#include "src/parser/statement/drop_statement.cpp"

#include "src/parser/statement/execute_statement.cpp"

#include "src/parser/statement/explain_statement.cpp"

#include "src/parser/statement/export_statement.cpp"

#include "src/parser/statement/insert_statement.cpp"

#include "src/parser/statement/load_statement.cpp"

#include "src/parser/statement/pragma_statement.cpp"

#include "src/parser/statement/prepare_statement.cpp"

#include "src/parser/statement/relation_statement.cpp"

#include "src/parser/statement/select_statement.cpp"

#include "src/parser/statement/set_statement.cpp"

#include "src/parser/statement/show_statement.cpp"

#include "src/parser/statement/transaction_statement.cpp"

#include "src/parser/statement/update_statement.cpp"

#include "src/parser/statement/vacuum_statement.cpp"

#include "src/parser/tableref.cpp"

#include "src/parser/tableref/basetableref.cpp"

#include "src/parser/tableref/crossproductref.cpp"

#include "src/parser/tableref/emptytableref.cpp"

#include "src/parser/tableref/expressionlistref.cpp"

#include "src/parser/tableref/joinref.cpp"

#include "src/parser/tableref/subqueryref.cpp"

#include "src/parser/tableref/table_function.cpp"

#include "src/parser/transform/constraint/transform_constraint.cpp"

#include "src/parser/transform/expression/transform_array_access.cpp"

#include "src/parser/transform/expression/transform_bool_expr.cpp"

#include "src/parser/transform/expression/transform_case.cpp"

#include "src/parser/transform/expression/transform_cast.cpp"

#include "src/parser/transform/expression/transform_coalesce.cpp"

#include "src/parser/transform/expression/transform_columnref.cpp"

#include "src/parser/transform/expression/transform_constant.cpp"

#include "src/parser/transform/expression/transform_expression.cpp"

#include "src/parser/transform/expression/transform_function.cpp"
